@@ -3,7 +3,7 @@ BEGIN {
   $Benchmark::Perl::Formance::AUTHORITY = 'cpan:SCHWIGON';
 }
 # ABSTRACT: Perl 5 performance benchmarking framework
-$Benchmark::Perl::Formance::VERSION = '0.48';
+$Benchmark::Perl::Formance::VERSION = '0.49';
 use 5.008;
 
 use warnings;
@@ -262,6 +262,18 @@ sub prepare_fast_system
         }
 }
 
+sub _error_printing
+{
+        my ($self, $pluginname, $error) = @_;
+
+        my @errors = split qr/\n/, $error;
+        my $maxerr = ($#errors < 10) ? $#errors : 10;
+        print STDERR "# Skip plugin '$pluginname'"             if $self->{options}{verbose};
+        print STDERR ":".$errors[0]                            if $self->{options}{verbose} > 1;
+        print STDERR join("\n# ", "", @errors[1..$maxerr])     if $self->{options}{verbose} > 2;
+        print STDERR "\n"                                      if $self->{options}{verbose};
+}
+
 sub run_plugin
 {
         my ($self, $pluginname) = @_;
@@ -280,16 +292,17 @@ sub run_plugin
                         close PARENT_RDR;
                         eval "use Benchmark::Perl::Formance::Plugin::$pluginname"; ## no critic
                         if ($@) {
-                                my @errors = split qr/\n/, $@;
-                                my $maxerr = ($#errors < 10) ? $#errors : 10;
-                                print STDERR "# Skip plugin '$pluginname'"             if $self->{options}{verbose};
-                                print STDERR ":".$errors[0]                            if $self->{options}{verbose} > 1;
-                                print STDERR join("\n# ", "", @errors[1..$maxerr])     if $self->{options}{verbose} > 2;
-                                print STDERR "\n"                                      if $self->{options}{verbose};
+                                $self->_error_printing($pluginname, $@);
                                 exit 0;
                         }
                         $0 = "benchmark-perl-formance-$pluginname";
-                        $res = &{"Benchmark::Perl::Formance::Plugin::${pluginname}::main"}($self->{options});
+                        eval {
+                                $res = &{"Benchmark::Perl::Formance::Plugin::${pluginname}::main"}($self->{options});
+                        };
+                        if ($@) {
+                                $self->_error_printing($pluginname, $@);
+                                $res = { failed => $@ };
+                        }
                         $res->{PLUGIN_VERSION} = ${"Benchmark::Perl::Formance::Plugin::${pluginname}::VERSION"};
                         store_fd($res, \*CHILD_WTR);
                         close CHILD_WTR;
