@@ -31,6 +31,7 @@ our $VERSION = "0.001";
 
 use File::ShareDir qw(dist_dir);
 use Benchmark ':hireswallclock';
+use Scalar::Util "reftype";
 
 our $PRINT = 0;
 
@@ -120,7 +121,7 @@ sub main
 
         my $result;
         my $t = timeit $count, sub { $result = run($goal) };
-        return $result if $result->{failed};
+        return $result if reftype($result) eq "HASH" and $result->{failed};
 
         return {
                 Benchmark => $t,
